==> haskell-optparse-simple-0.1.1.2-53-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.1.1.2
id: optparse-simple-0.1.1.2-18GFMPmbU20GnhFyzFIB0w
key: optparse-simple-0.1.1.2-18GFMPmbU20GnhFyzFIB0w
license: BSD-3-Clause
copyright: 2015-2017 FP Complete
maintainer: chrisdone@fpcomplete.com
author: FP Complete
homepage: https://github.com/fpco/optparse-simple#readme
synopsis: Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>
category: Options
abi: 40781830a8c314338fe968176f81d99d
exposed: True
exposed-modules:
    Options.Applicative.Simple
hidden-modules: Paths_optparse_simple
import-dirs: /usr/lib/ghc-8.6.5/site-local/optparse-simple-0.1.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/optparse-simple-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/optparse-simple-0.1.1.2
hs-libraries: HSoptparse-simple-0.1.1.2-18GFMPmbU20GnhFyzFIB0w
depends:
    base-4.12.0.0 githash-0.1.3.1-DZ4yoco9PS4H4anGYtOmd
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    template-haskell-2.14.0.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-simple-0.1.1.2-68-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.1.1.2
id: optparse-simple-0.1.1.2-LLppadFJjp2GThzlArTgPn
key: optparse-simple-0.1.1.2-LLppadFJjp2GThzlArTgPn
license: BSD-3-Clause
copyright: 2015-2017 FP Complete
maintainer: chrisdone@fpcomplete.com
author: FP Complete
homepage: https://github.com/fpco/optparse-simple#readme
synopsis: Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>
category: Options
abi: 20b17a16cc62a4c58a7169c21e08dab5
exposed: True
exposed-modules:
    Options.Applicative.Simple
hidden-modules: Paths_optparse_simple
import-dirs: /usr/lib/ghc-8.6.5/site-local/optparse-simple-0.1.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/optparse-simple-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/optparse-simple-0.1.1.2
hs-libraries: HSoptparse-simple-0.1.1.2-LLppadFJjp2GThzlArTgPn
depends:
    base-4.12.0.0 githash-0.1.3.2-5eYkblJ8BnCJh84sUlA9CK
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    template-haskell-2.14.0.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
